@@ -7,6 +7,9 @@ mod debug_impl;
 #[cfg(feature="serde1")]
 mod serde_impl;
 
+mod extra;
+
+#[derive(Clone, Eq, Ord, PartialEq, PartialOrd, Hash)]
 pub struct RawPom<T> { 
     next_id: u64,
     pub(crate) members: BTreeMap<Id<T>, T>
@@ -20,6 +23,7 @@ impl<T> RawPom<T> {
         }
     }
 
+    #[cfg(feature="serde1")]  // only needs to exist for serde
     pub(crate) fn from_raw_parts(next_id: u64, members: BTreeMap<Id<T>, T>) -> RawPom<T> {
         RawPom { next_id, members }
     }
